@@ -545,7 +545,7 @@ class SofaScore:
       res = json.loads(response.text.encode('utf8'))
       return res
     except:
-      return {"error":"oops"}
+      pass
 
 
   # Get detailed stats for one player
